@@ -154,7 +154,7 @@ FIELDS_NO_FLOAT_CONVERT = {"summary.weave.latency_ms"}
 
 
 def py_to_api_filter(filter: tsi.CallsFilter | None) -> tsi.CallsFilter | None:
-    """Convert Saved View Filter to API Filter"""
+    """Convert Saved View Filter to API Filter."""
     if filter is None:
         return None
     return tsi.CallsFilter(
@@ -751,7 +751,8 @@ class SavedView:
     def ui_url(self) -> str | None:
         """URL to show this saved view in the UI.
 
-        Note this is the "result" page with traces etc, not the URL for the view object."""
+        Note this is the "result" page with traces etc, not the URL for the view object.
+        """
         if self.ref and self.entity and self.project:
             weave_root = urls.project_weave_root_url(self.entity, self.project)
             return f"{weave_root}/{self.view_type}?view={self.ref.name}"
