@@ -3,16 +3,15 @@ from typing import Any
 from pydantic import BaseModel, ValidationError
 
 import weave
-from weave.scorers.base_scorer import Scorer
 
 
-class PydanticScorer(Scorer):
+class PydanticScorer(weave.Scorer):
     """Validate the model output against a pydantic model."""
 
     model: type[BaseModel]
 
     @weave.op
-    def score(self, output: Any) -> dict:
+    def score(self, *, output: Any, **kwargs: Any) -> dict:
         if isinstance(output, str):
             try:
                 self.model.model_validate_json(output)
