@@ -2,11 +2,11 @@ from __future__ import annotations
 
 import logging
 import os
+from json import JSONDecodeError
 
 from weave.compat import wandb
 from weave.telemetry import trace_sentry
 from weave.trace import (
-    autopatch,
     env,
     init_message,
     weave_client,
@@ -74,10 +74,22 @@ Args:
 """
 
 
+def _weave_is_available(server: remote_http_trace_server.RemoteHTTPTraceServer) -> bool:
+    try:
+        server.server_info()
+    except JSONDecodeError:
+        return False
+    except Exception:
+        logger.warning(
+            "Unexpected error when checking if Weave is available on the server.  Please contact support."
+        )
+        return False
+    return True
+
+
 def init_weave(
     project_name: str,
     ensure_project_exists: bool = True,
-    autopatch_settings: autopatch.AutopatchSettings | None = None,
 ) -> weave_client.WeaveClient:
     if not project_name or not project_name.strip():
         raise ValueError("project_name must be non-empty")
@@ -121,6 +133,10 @@ def init_weave(
         api_key = wandb_context.api_key
 
     remote_server = init_weave_get_server(api_key)
+    if not _weave_is_available(remote_server):
+        raise RuntimeError(
+            "Weave is not available on the server.  Please contact support."
+        )
     server: TraceServerInterface = remote_server
     if use_server_cache():
         server = CachingMiddlewareTraceServer.from_env(server)
@@ -134,10 +150,13 @@ def init_weave(
 
     weave_client_context.set_weave_client_global(client)
 
-    # autopatching is only supported for the wandb client, because OpenAI calls are not
-    # logged in local mode currently. When that's fixed, this autopatch call can be
-    # moved elsewhere
-    autopatch.autopatch(autopatch_settings)
+    # Implicit patching:
+    # 1. Check sys.modules and automatically patch any already-imported integrations
+    # 2. Register import hook to patch integrations imported after weave.init()
+    from weave.integrations.patch import implicit_patch, register_import_hook
+
+    implicit_patch()
+    register_import_hook()
 
     username = get_username()
 
@@ -225,8 +244,9 @@ def finish() -> None:
     if current_client is not None:
         weave_client_context.set_weave_client_global(None)
 
-    # autopatching is only supported for the wandb client, because OpenAI calls are not
-    # logged in local mode currently. When that's fixed, this reset_autopatch call can be
-    # moved elsewhere
-    autopatch.reset_autopatch()
+    # Unregister the import hook
+    from weave.integrations.patch import unregister_import_hook
+
+    unregister_import_hook()
+
     trace_sentry.global_trace_sentry.end_session()
