@@ -1,11 +1,11 @@
-"""
-A lightweight ORM layer for ClickHouse/SQLite.
+"""A lightweight ORM layer for ClickHouse/SQLite.
 Abstracts away some of their differences and allows building up SQL queries in a safe way.
 """
 
 import datetime
 import json
 import typing
+from dataclasses import dataclass
 
 from pydantic import BaseModel
 from typing_extensions import TypeAlias
@@ -208,17 +208,11 @@ class PreparedSelect(BaseModel):
     fields: list[str]
 
 
+@dataclass
 class Join:
-    join_type: typing.Optional[str]
     table: Table
     query: tsi.Query
-
-    def __init__(
-        self, table: Table, query: tsi.Query, join_type: typing.Optional[str] = None
-    ):
-        self.join_type = join_type
-        self.table = table
-        self.query = query
+    join_type: typing.Optional[str]
 
 
 class Select:
@@ -518,7 +512,7 @@ def clickhouse_cast(
 def quote_json_path(path: str) -> str:
     """Helper function to quote a json path for use in a clickhouse query. Moreover,
     this converts index operations from dot notation (conforms to Mongo) to bracket
-    notation (required by clickhouse)
+    notation (required by clickhouse).
 
     See comments on `GetFieldOperator` for current limitations
     """
