@@ -7,6 +7,7 @@ import logging
 from weave.trace.serialization import serializer
 from weave.trace.serialization.custom_objs import MemTraceFilesArtifact
 from weave.utils.invertable_dict import InvertableDict
+from weave.utils.iterators import first
 
 try:
     from PIL import Image
@@ -57,7 +58,7 @@ def save(obj: Image.Image, artifact: MemTraceFilesArtifact, name: str) -> None:
 
 def load(artifact: MemTraceFilesArtifact, name: str) -> Image.Image:
     # Today, we assume there can only be 1 image in the artifact.
-    filename = next(iter(artifact.path_contents))
+    filename = first(artifact.path_contents)
     if not filename.startswith("image."):
         raise ValueError(f"Expected filename to start with 'image.', got {filename}")
 
