@@ -2,21 +2,36 @@ from __future__ import annotations
 
 import base64
 import hashlib
+import json
 import logging
 import os
+import re
 import subprocess
 import sys
 import uuid
 from pathlib import Path
 from typing import Annotated, Any, Generic
+from urllib.parse import quote_from_bytes, urlparse
 
-from pydantic import BaseModel, Field, PrivateAttr
+from pydantic import BaseModel, Field, PrivateAttr, field_serializer
 from typing_extensions import Self, TypeVar
 
 from weave.trace.refs import Ref
 from weave.trace.serialization.mem_artifact import MemTraceFilesArtifact
-
-from .content_types import ContentType, ResolvedContentArgs, ValidContentInputs
+from weave.type_wrappers.Content.content_types import (
+    ContentType,
+    ResolvedContentArgs,
+    ValidContentInputs,
+)
+from weave.type_wrappers.Content.utils import (
+    default_filename,
+    full_name,
+    get_mime_and_extension,
+    is_valid_b64,
+    is_valid_path,
+    match_data_url,
+    try_parse_data_url,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -26,15 +41,16 @@ T = TypeVar("T", bound=str)
 
 
 class Content(BaseModel, Generic[T]):
-    """
-    A class to represent content from various sources, resolving them
+    """A class to represent content from various sources, resolving them
     to a unified byte-oriented representation with associated metadata.
 
     This class must be instantiated using one of its classmethods:
     - from_path()
     - from_bytes()
     - from_text()
+    - from_url()
     - from_base64()
+    - from_data_url()
     """
 
     # This is required due to some attribute setting done by our serialization layer
@@ -72,8 +88,7 @@ class Content(BaseModel, Generic[T]):
     _art: MemTraceFilesArtifact | None = PrivateAttr(None)
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
-        """
-        Direct initialization is disabled.
+        """Direct initialization is disabled.
         Please use a classmethod like `Content.from_path()` to create an instance.
         """
         raise NotImplementedError(
@@ -82,6 +97,66 @@ class Content(BaseModel, Generic[T]):
             "If you must accept arbitrary inputs, Content._from_guess infers which method to use."
         )
 
+    @classmethod
+    def model_validate(
+        cls: type[Self],
+        obj: Any,
+        *,
+        strict: bool | None = None,
+        from_attributes: bool | None = None,
+        context: dict[str, Any] | None = None,
+    ) -> Self:
+        """Override model_validate to handle Content reconstruction from dict."""
+        if isinstance(obj, dict):
+            # Check if this is a full Content dict (from deserialization)
+            required_fields = {
+                "id",
+                "data",
+                "size",
+                "mimetype",
+                "digest",
+                "filename",
+                "content_type",
+                "input_type",
+            }
+            if required_fields.issubset(obj.keys()):
+                # Handle data field deserialization
+                data = obj.get("data")
+                if isinstance(data, str):
+                    # Check if it was base64 encoded during serialization
+                    content_type = obj.get("content_type", "")
+                    if "base64" in content_type:
+                        # Decode from base64
+                        obj["data"] = base64.b64decode(data)
+                    else:
+                        # Decode from string using encoding
+                        encoding = obj.get("encoding", "utf-8")
+                        obj["data"] = data.encode(encoding)
+                # Use model_construct to bypass __init__
+                return cls.model_construct(**obj)
+
+        # Fall back to parent implementation for other cases
+        return super().model_validate(
+            obj, strict=strict, from_attributes=from_attributes, context=context
+        )
+
+    @classmethod
+    def model_validate_json(
+        cls: type[Self],
+        json_data: str | bytes | bytearray,
+        *,
+        strict: bool | None = None,
+        context: dict[str, Any] | None = None,
+    ) -> Self:
+        """Override model_validate_json to handle Content reconstruction from JSON."""
+        # Parse the JSON
+        if isinstance(json_data, (bytes, bytearray)):
+            json_data = json_data.decode("utf-8")
+        obj = json.loads(json_data)
+
+        # Use our custom model_validate
+        return cls.model_validate(obj, strict=strict, context=context)
+
     @classmethod
     def from_bytes(
         cls: type[Self],
@@ -93,8 +168,6 @@ class Content(BaseModel, Generic[T]):
         encoding: str = "utf-8",
     ) -> Self:
         """Initializes Content from raw bytes."""
-        from .utils import default_filename, full_name, get_mime_and_extension
-
         if len(data) == 0:
             logger.warning("Content.from_bytes received empty data")
 
@@ -137,8 +210,6 @@ class Content(BaseModel, Generic[T]):
         encoding: str = "utf-8",
     ) -> Self:
         """Initializes Content from a string of text."""
-        from .utils import default_filename, full_name, get_mime_and_extension
-
         if len(text) == 0:
             logger.warning("Content.from_text received empty text")
 
@@ -188,8 +259,6 @@ class Content(BaseModel, Generic[T]):
         metadata: dict[str, Any] | None = None,
     ) -> Self:
         """Initializes Content from a base64 encoded string or bytes."""
-        from .utils import default_filename, full_name, get_mime_and_extension
-
         if len(b64_data) == 0:
             logger.warning("Content.from_base64 received empty input")
 
@@ -242,8 +311,6 @@ class Content(BaseModel, Generic[T]):
         metadata: dict[str, Any] | None = None,
     ) -> Self:
         """Initializes Content from a local file path."""
-        from .utils import full_name, get_mime_and_extension, is_valid_path
-
         path_obj = Path(path)
         if not is_valid_path(path_obj):
             raise FileNotFoundError(f"File not found at path: {path_obj}")
@@ -284,6 +351,125 @@ class Content(BaseModel, Generic[T]):
         # Use model_construct to bypass our custom __init__
         return cls.model_construct(**resolved_args)
 
+    @classmethod
+    def from_data_url(
+        cls: type[Self], url: str, /, metadata: dict[str, Any] | None = None
+    ) -> Self:
+        """Initializes Content from a data URL."""
+        parsed = try_parse_data_url(url)
+        if not parsed:
+            raise ValueError("Invalid data URL provided.")
+
+        content_type = parsed.params.content_type
+        encoding = parsed.params.encoding
+        data = parsed.params.data
+        mimetype = parsed.params.mimetype
+
+        digest = hashlib.sha256(data).hexdigest()
+        size = len(data)
+
+        mimetype, extension = get_mime_and_extension(
+            mimetype=mimetype, extension=None, filename=None, buffer=data
+        )
+        filename = default_filename(
+            extension=extension, mimetype=mimetype, digest=digest
+        )
+
+        resolved_args: ResolvedContentArgs = {
+            "id": uuid.uuid4().hex,
+            "data": data,
+            "size": size,
+            "mimetype": mimetype,
+            "digest": digest,
+            "filename": filename,
+            "content_type": content_type,
+            "input_type": full_name(url),
+            "extension": extension,
+            "encoding": encoding,
+        }
+
+        if metadata:
+            resolved_args["metadata"] = metadata
+
+        # Use model_construct to bypass our custom __init__
+        return cls.model_construct(**resolved_args)
+
+    @classmethod
+    def from_url(
+        cls: type[Self],
+        url: str,
+        /,
+        headers: dict[str, Any] | None = None,
+        timeout: int | None = 30,
+        metadata: dict[str, Any] | None = None,
+    ) -> Self:
+        """Initializes Content by fetching bytes from an HTTP(S) URL.
+
+        Downloads the content, infers mimetype/extension from headers, URL path,
+        and data, and constructs a Content object from the resulting bytes.
+        """
+        # Use our shared HTTP session with logging adapter
+        # Local import to prevent importing requests unless necessary
+        from weave.utils import http_requests as http_requests
+
+        resp = http_requests.get(url, headers=headers, timeout=timeout)
+        resp.raise_for_status()
+
+        data = resp.content or b""
+        digest = hashlib.sha256(data).hexdigest()
+        size = len(data)
+
+        # Try to get mimetype from header (strip any charset)
+        header_ct = resp.headers.get("Content-Type", "")
+        mimetype_from_header = header_ct.split(";")[0].strip() if header_ct else None
+
+        # Try to get filename from Content-Disposition or URL path
+        filename_from_header = None
+        cd = resp.headers.get("Content-Disposition", "")
+        if "filename=" in cd:
+            # naive extraction; handles filename="..." or filename=...
+            match = re.search(
+                r"filename\*=.*?''([^;\r\n]+)|filename=\"?([^;\r\n\"]+)\"?", cd
+            )
+            if match:
+                filename_from_header = match.group(1) or match.group(2)
+
+        parsed_url = urlparse(url)
+        url_basename = Path(parsed_url.path).name if parsed_url.path else None
+        filename_hint = filename_from_header or url_basename
+
+        mimetype, extension = get_mime_and_extension(
+            mimetype=mimetype_from_header,
+            extension=Path(filename_hint).suffix if filename_hint else None,
+            filename=filename_hint,
+            buffer=data,
+        )
+
+        filename = (
+            filename_hint
+            if filename_hint
+            else default_filename(extension, mimetype, digest)
+        )
+
+        resolved_args: ResolvedContentArgs = {
+            "id": uuid.uuid4().hex,
+            "data": data,
+            "size": size,
+            "mimetype": mimetype,
+            "digest": digest,
+            "filename": filename,
+            "content_type": "bytes",
+            "input_type": full_name(url),
+            "extension": extension,
+            # Use requests-detected encoding if present, else utf-8
+            "encoding": resp.encoding or "utf-8",
+        }
+
+        if metadata:
+            resolved_args["metadata"] = metadata
+
+        return cls.model_construct(**resolved_args)
+
     @classmethod
     def _from_guess(
         cls: type[Self],
@@ -292,8 +478,6 @@ class Content(BaseModel, Generic[T]):
         extension: str | None = None,
         mimetype: str | None = None,
     ) -> Self:
-        from .utils import is_valid_b64, is_valid_path
-
         # First check if it is a path, we only check validity for str scenario
         # because we have dedicated error message for invalid path
         if isinstance(input, Path) or (isinstance(input, str) and is_valid_path(input)):
@@ -305,24 +489,61 @@ class Content(BaseModel, Generic[T]):
 
         # If it is still a str - treat as raw text
         elif isinstance(input, str):
+            if match_data_url(input):
+                return cls.from_data_url(input)
+            # Match http or https URLs
+            if re.match(r"^https?://", input):
+                return cls.from_url(input)
+
             return cls.from_text(input, mimetype=mimetype, extension=extension)
 
         return cls.from_bytes(input, mimetype=mimetype, extension=extension)
 
     @classmethod
     def _from_resolved_args(cls: type[Self], /, args: ResolvedContentArgs) -> Self:
-        """
-        Initializes Content from pre-existing ResolvedContentArgs
-        This is for internal use to reconstruct the Content object by the serialization layer
+        """Initializes Content from pre-existing ResolvedContentArgs
+        This is for internal use to reconstruct the Content object by the serialization layer.
         """
         return cls.model_construct(**args)
 
-    def as_string(self) -> str:
+    def to_data_url(self, use_base64: bool = True) -> str:
+        """Constructs a data URL from the content.
+
+        Args:
+            use_base64: If True, the data will be base64 encoded.
+                        Otherwise, it will be percent-encoded. Defaults to True.
+
+        Returns:
+            A data URL string.
         """
-        Display the data as a string. Bytes are decoded using the `encoding` attribute
+        header = f"data:{self.mimetype}"
+        if (
+            self.mimetype.startswith("text/")
+            and self.content_type.find(":encoding") != -1
+        ):
+            # Only add charset for text types
+            header += f";charset={self.encoding}"
+
+        if use_base64 or self.content_type.find(":base64"):
+            encoded_data = base64.b64encode(self.data).decode("ascii")
+            return f"{header};base64,{encoded_data}"
+        else:
+            encoded_data = quote_from_bytes(self.data)
+            return f"{header},{encoded_data}"
+
+    @field_serializer("data", when_used="json")
+    def serialize_data(self, data: bytes) -> str:
+        """When dumping model in json mode"""
+        if self.content_type.find("base64") != -1:
+            return base64.b64encode(data).decode("ascii")
+
+        return data.decode(encoding=self.encoding)
+
+    def as_string(self) -> str:
+        """Display the data as a string. Bytes are decoded using the `encoding` attribute
         If base64, the data will be re-encoded to base64 bytes then decoded to an ASCII string
         Returns:
-            str
+            str.
         """
         if self.encoding == "base64":
             return base64.b64encode(self.data).decode("ascii")
@@ -360,7 +581,7 @@ class Content(BaseModel, Generic[T]):
 
     def save(self, dest: str | Path) -> None:
         """Copy the file to the specified destination path.
-        Updates the filename and the path of the content to reflect the last saved copy
+        Updates the filename and the path of the content to reflect the last saved copy.
 
         Args:
             dest: Destination path where the file will be copied to (string or pathlib.Path)
